==> nextcloud-14.0.13.zip: nextcloud/apps/password_policy/l10n/de.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "Das Passwort muss mindestens %s Zeichen lang sein",
    "Password needs to contain at least one lower and one upper case character." : "Das Passwort muss mindestens einen Klein- und einen Großbuchstaben beinhalten. ",
    "Password needs to contain at least one numeric character." : "Das Passwort muss mindestens eine Zahl beinhalten. ",
    "Password needs to contain at least one special character." : "Das Passwort muss mindestens ein Sonderzeichen beinhalten. ",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Das Passwort ist unter den 1.000.000 häufigsten Passwörtern. Bitte wähle ein anderes.",
    "Password is present in compromised password list. Please choose a different password." : "Das Passwort ist in der Liste der kompromittierten Passwörter enthalten. Bitte wähle ein anderes Passwort. ",
    "Password policy" : "Passwort-Regeln",
    "Allows admins to configure a password policy" : "Ermöglicht Administratoren eine Passwortrichtlinie einzurichten",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Ermöglicht Administratoren diverse Voreinstellungen für Passwörter vorzunehmen, z.B. die Mindestlänge",
    "Minimal length" : "Minimale Länge",
    "Forbid common passwords" : "Häufig verwendete Passwörter verbieten",
    "Enforce upper and lower case characters" : "Groß- und Kleinbuchstaben erzwingen",
    "Enforce numeric characters" : "Zahlen erzwingen",
    "Enforce special characters" : "Sonderzeichen erzwingen",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Das Passwort gegen eine Liste von geknackten Passwörtern bei haveibeenpwned.com prüfen.",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Es wird ein Hash des Passwortes erstellt und dessen ersten 5 Zeichen an haveibeenpwned.com gesendet. Danach wird eine Liste aller Hashes empfangen, welche mit diesen 5 Zeichen beginnen. Nextcloud prüft nun ob der Hash des eingegebenen Passwortes in der Liste der Hashes enthalten ist."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.6.zip: nextcloud/apps/password_policy/l10n/de.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Das Passwort ist abgelaufen, bitte die Methode \"Passwort vergessen\" zum Zurücksetzen verwenden",
    "Password must not have been used recently before." : "Das Passwort darf noch nicht verwendet worden sein.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Das Passwort ist unter den 1.000.000 häufigsten Passwörtern. Bitte wähle ein anderes.",
    "Password is present in compromised password list. Please choose a different password." : "Das Passwort ist in der Liste der kompromittierten Passwörter enthalten. Bitte wähle ein anderes Passwort. ",
    "Password needs to be at least %s characters long" : "Das Passwort muss mindestens %s Zeichen lang sein",
    "Password needs to contain at least one numeric character." : "Das Passwort muss mindestens eine Zahl beinhalten. ",
    "Password needs to contain at least one special character." : "Das Passwort muss mindestens ein Sonderzeichen beinhalten. ",
    "Password needs to contain at least one lower and one upper case character." : "Das Passwort muss mindestens einen Klein- und einen Großbuchstaben beinhalten. ",
    "Password policy" : "Passwort-Regeln",
    "Allows admins to configure a password policy" : "Ermöglicht Administratoren eine Passwortrichtlinie einzurichten",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Ermöglicht Administratoren diverse Voreinstellungen für Passwörter vorzunehmen, z. B. die Mindestlänge",
    "Minimal length" : "Minimale Länge",
    "User password history" : "Benutzerpasswort-Verlauf",
    "days until user password expires" : "Tage bis zum Ablauf des Benutzerpassworts",
    "Forbid common passwords" : "Häufig verwendete Passwörter verbieten",
    "Enforce upper and lower case characters" : "Groß- und Kleinbuchstaben erzwingen",
    "Enforce numeric characters" : "Zahlen erzwingen",
    "Enforce special characters" : "Sonderzeichen erzwingen",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Das Passwort gegen eine Liste von geknackten Passwörtern bei haveibeenpwned.com prüfen.",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Es wird ein Hash des Passwortes erstellt und dessen ersten 5 Zeichen an haveibeenpwned.com gesendet. Danach wird eine Liste aller Hashes empfangen, welche mit diesen 5 Zeichen beginnen. Nextcloud prüft nun ob der Hash des eingegebenen Passwortes in der Liste der Hashes enthalten ist."
},
"nplurals=2; plural=(n != 1);");
